Stan Math Library: stan/math/fwd/scal/fun/sinh.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

sinh.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_SINH_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_SINH_HPP
3
4 #include <stan/math/fwd/core.hpp>
5
6
7 namespace stan {
8
9 namespace math {
10
11 template <typename T>
12 inline
13 fvar<T>
14 sinh(const fvar<T>& x) {
15 using std::sinh;
16 using std::cosh;
17 return fvar<T>(sinh(x.val_),
18 x.d_ * cosh(x.val_));
19 }
20 }
21 }
22 #endif
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan::math::cosh
fvar< T > cosh(const fvar< T > &x)
Definition: cosh.hpp:13
stan
Definition: log_sum_exp.hpp:8
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::sinh
fvar< T > sinh(const fvar< T > &x)
Definition: sinh.hpp:14
stan::math::sinh
var sinh(const var &a)
Return the hyperbolic sine of the specified variable (cmath).
Definition: sinh.hpp:49
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.